Duration

Struct Duration 

pub struct Duration { /* private fields */ }
Signed duration, represented as seconds and normalized nanoseconds.

Implementations

Source

impl Duration

pub const ZERO: Duration

pub fn new(seconds: i64, nanos: i32) -> Result<Duration, Error>

Creates a duration from seconds and a nanosecond adjustment.

pub fn from_normalized(seconds: i64, nanos: u32) -> Result<Duration, Error>

Creates a duration from normalized seconds and nanoseconds.

pub fn from_parts(seconds: i64, nanos: i64) -> Result<Duration, Error>

Creates a duration from seconds and an arbitrary nanosecond adjustment.

pub const fn from_secs(seconds: i64) -> Duration

Creates a duration from whole seconds.

pub fn from_minutes(minutes: i64) -> Result<Duration, Error>

Creates a duration from minutes.

pub fn from_hours(hours: i64) -> Result<Duration, Error>

Creates a duration from hours.

pub fn from_days(days: i64) -> Result<Duration, Error>

Creates a duration from days.

pub fn from_millis(millis: i64) -> Duration

Creates a duration from milliseconds.

pub fn from_micros(micros: i64) -> Duration

Creates a duration from microseconds.

pub fn from_nanos(nanos: i128) -> Result<Duration, Error>

Creates a duration from nanoseconds.

pub const fn seconds(self) -> i64

Returns the normalized seconds component.

pub const fn subsec_nanos(self) -> u32

Returns the normalized nanosecond component.

pub const fn is_zero(self) -> bool

Returns whether this duration is zero.

pub const fn is_positive(self) -> bool

Returns whether this duration is greater than zero.

pub const fn is_negative(self) -> bool

Returns whether this duration is less than zero.

pub fn to_millis(self) -> Result<i64, Error>

Returns whole milliseconds, rounded down for sub-millisecond values.

pub fn to_micros(self) -> Result<i64, Error>

Returns whole microseconds, rounded down for sub-microsecond values.

pub fn to_nanos(self) -> i128

Returns nanoseconds.

pub fn checked_add(self, other: Duration) -> Result<Duration, Error>

Adds two durations.

pub fn checked_sub(self, other: Duration) -> Result<Duration, Error>

Subtracts other from this duration.

pub fn checked_neg(self) -> Result<Duration, Error>

Negates this duration.

pub fn abs(self) -> Result<Duration, Error>

Returns the absolute duration.