RcWeak

Struct RcWeak 

pub struct RcWeak<T>
where T: ?Sized,
{ /* private fields */ }
A serializable runtime wrapper around std::rc::Weak<T>.

RcWeak<T> is designed for graph-like structures where nodes may need to hold non-owning references to other nodes, and you still want them to round-trip through serialization while preserving reference identity.

Implementations

Source

impl<T> RcWeak<T>

pub fn new() -> RcWeak<T>

Source

impl<T> RcWeak<T>
where T: ?Sized,

pub fn upgrade(&self) -> Option<Rc<T>>

pub fn strong_count(&self) -> usize

pub fn weak_count(&self) -> usize

pub fn ptr_eq(&self, other: &RcWeak<T>) -> bool

pub fn update(&self, weak: Weak<T>)

pub fn from_std(weak: Weak<T>) -> RcWeak<T>