pub struct Duration { /* private fields */ }Expand description
Signed duration, represented as seconds and normalized nanoseconds.
Implementations
Sourceimpl Duration
impl Duration
pub const ZERO: Duration
Sourcepub fn new(seconds: i64, nanos: i32) -> Result<Duration, Error>
pub fn new(seconds: i64, nanos: i32) -> Result<Duration, Error>
Creates a duration from seconds and a nanosecond adjustment.
Sourcepub fn from_normalized(seconds: i64, nanos: u32) -> Result<Duration, Error>
pub fn from_normalized(seconds: i64, nanos: u32) -> Result<Duration, Error>
Creates a duration from normalized seconds and nanoseconds.
Sourcepub fn from_parts(seconds: i64, nanos: i64) -> Result<Duration, Error>
pub fn from_parts(seconds: i64, nanos: i64) -> Result<Duration, Error>
Creates a duration from seconds and an arbitrary nanosecond adjustment.
Sourcepub fn from_millis(millis: i64) -> Duration
pub fn from_millis(millis: i64) -> Duration
Creates a duration from milliseconds.
Sourcepub fn from_micros(micros: i64) -> Duration
pub fn from_micros(micros: i64) -> Duration
Creates a duration from microseconds.
Sourcepub const fn subsec_nanos(self) -> u32
pub const fn subsec_nanos(self) -> u32
Returns the normalized nanosecond component.
Sourcepub const fn is_positive(self) -> bool
pub const fn is_positive(self) -> bool
Returns whether this duration is greater than zero.
Sourcepub const fn is_negative(self) -> bool
pub const fn is_negative(self) -> bool
Returns whether this duration is less than zero.
Sourcepub fn to_millis(self) -> Result<i64, Error>
pub fn to_millis(self) -> Result<i64, Error>
Returns whole milliseconds, rounded down for sub-millisecond values.
Sourcepub fn to_micros(self) -> Result<i64, Error>
pub fn to_micros(self) -> Result<i64, Error>
Returns whole microseconds, rounded down for sub-microsecond values.
Sourcepub fn checked_sub(self, other: Duration) -> Result<Duration, Error>
pub fn checked_sub(self, other: Duration) -> Result<Duration, Error>
Subtracts other from this duration.
Sourcepub fn checked_neg(self) -> Result<Duration, Error>
pub fn checked_neg(self) -> Result<Duration, Error>
Negates this duration.